Package 'WRShd'

Title: An Experimental Refactor of the Harrell-Davis Estimate Functions from R. R. Wilcox' Robust Statistics Package "WRS"
Description: This package is an experimental refactored version of the "WRS" package, which implements R. R. Wilcox' the robust statistics functions. The package currently focuses on implementing functions related to the Harrell-Davis estimator.
Authors: Masahiro Kanai, Rand R. Wilcox, Felix Schonbrodt
Maintainer: Masahiro Kanai <[email protected]>
License: GPL (>= 2)
Version: 0.1
Built: 2026-07-04 08:32:10 UTC
Source: https://github.com/mkanai/WRShd

Help Index


Compute the Harrell-Davis estimate of the qth quantile

Description

Compute the Harrell-Davis estimate of the qth quantile

Usage

hd(x, q = 0.5, na.rm = TRUE, cores = 1)

Arguments

x

a numeric vector

q

a desired quantile

na.rm

a logical indicating whether missing values should be checked for removal

cores

a number of cores used for computation

Value

the Harrell-Davis estimate of the qth quantile of x


Compute a 1-alpha confidence for the Harrell-Davis estimate of the qth quantile

Description

Compute a 1-alpha confidence for the Harrell-Davis estimate of the qth quantile

Usage

hdci(x, q = 0.5, alpha = 0.05, nboot = 100, SEED = TRUE, pr = TRUE,
  cores = 1)

Arguments

x

a numeric vector

q

a desired quantile

alpha

a significance level

nboot

a number of bootstraps

SEED

a logical indicating whether the seed should be set

pr

a logical indicating whether

cores

a number of cores used for computation

Value

the 1-alpha confidence for the Harrell-Davis estimate of the qth quantile


Compute a bootstrap 1-alpha confidence for the Harrell-Davis estimate of the qth quantile

Description

Compute a bootstrap 1-alpha confidence for the Harrell-Davis estimate of the qth quantile

Usage

hdpb(x, q = 0.5, alpha = 0.05, nboot = 2000, SEED = TRUE, nv = 0,
  cores = 1)

Arguments

x

a numeric vector

q

a desired quantile

alpha

a significance level

nboot

a number of bootstraps

SEED

a logical indicating whether the seed should be set

nv

a null-value when computing a p-value

cores

a number of cores used for computation

Value

the a bootstrap 1-alpha confidence for the Harrell-Davis estimate of the qth quantile


Compute a bootstrap standard error of the Harrell-Davis estimate of the qth quantile

Description

Compute a bootstrap standard error of the Harrell-Davis estimate of the qth quantile

Usage

hdseb(x, q = 0.5, nboot = 100, SEED = TRUE, cores = 1)

Arguments

x

a numeric vector

q

a desired quantile

nboot

a number of bootstraps

SEED

a logical indicating whether the seed should be set

cores

a number of cores used for computation

Value

the standard error of the Harrell-Davis estimate of the qth quantile


Compare quantiles via the Harrell-Davis estimator

Description

Compare quantiles via the Harrell-Davis estimator

Usage

qcomhd(x, y, q = c(0.1, 0.25, 0.5, 0.75, 0.9), nboot = 2000,
  plotit = TRUE, SEED = TRUE, xlab = "Group 1", ylab = "Est.1-Est.2",
  alpha = 0.05, cores = 1)

Arguments

x

a numeric vector

y

a numeric vector

q

a desired quantile

nboot

a number of bootstraps

plotit

a logical indicating whether plotting the result

SEED

a logical indicating whether the seed should be set

xlab

a string of x-axis label

ylab

a string of y-axis label

alpha

a significance level

cores

a number of cores used for computation


Compare quantiles via the Harrell-Davis estimator

Description

Compare quantiles via the Harrell-Davis estimator

Usage

qcomhdMC(x, y, q = c(0.1, 0.25, 0.5, 0.75, 0.9), nboot = 2000,
  plotit = TRUE, SEED = TRUE, xlab = "Group 1", ylab = "Est.1-Est.2",
  alpha = 0.05, cores = -1)

Arguments

x

a numeric vector

y

a numeric vector

q

a desired quantile

nboot

a number of bootstraps

plotit

a logical indicating whether plotting the result

SEED

a logical indicating whether the seed should be set

xlab

a string of x-axis label

ylab

a string of y-axis label

alpha

a significance level

cores

a number of cores used for computation


WRShd

Description

An Experimental Refactor of the Harrell-Davis Estimate Functions from R. R. Wilcox' Robust Statistics Package "WRS"

Author(s)

Masahiro Kanai

Rand R. Wilcox

Felix Schönbrodt